OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Loading accounts" : "Chargement des comptes",
    "Error while loading the accounts." : "Erreur lors du chargement des comptes.",
    "Error while loading the selected account." : "Erreur lors du chargement du compte sélectionné.",
    "Can not load this folder." : "Impossible de charger ce dossier.",
    "Searching for {query}" : "Recherche pour {query}",
    "Error while deleting message." : "Erreur lors de la suppression du message.",
    "Forwarded message" : "Message transféré",
    "Choose a folder to store the attachment in" : "Choisissez le dossier dans lequel enregistrer la pièce jointe",
    "Attachments saved to Files." : "Pièces jointes enregistrées dans les Fichiers.",
    "Attachment saved to Files." : "Pièce jointe enregistrée dans les Fichiers.",
    "Error while saving attachments to Files." : "Erreur lors de l'enregistrement des pièces jointes dans les Fichiers.",
    "Error while saving attachment to Files." : "Erreur lors de l'enregistrement de la pièce jointe dans les Fichiers.",
    "Message flag could not be set." : "Le drapeau n'a pas été ajouté sur le message.",
    "Could not move message." : "Impossible de déplacer le message.",
    "Invalid account" : "Compte invalide",
    "Invalid folder" : "Dossier invalide",
    "Error while creating the account: " : "Erreur lors de la création du compte:",
    "Unknown error" : "Erreur inconnue",
    "All inboxes" : "Toutes les boîtes",
    "you" : "vous",
    "Send message to {email}" : "Envoyer un mail à {email}",
    "Could not load {tag}{name}{endtag}" : "Impossible de charger {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Nous ne pouvons pas charger {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Il y a eu un problème de chargement {tag}{name}{endtag}",
    "We couldn’t load your message" : "Nous ne pouvons pas charger votre message",
    "Unable to load the desired message" : "Impossible de charger le message souhaité",
    "There was a problem loading the message" : "Il y a eu un problème de chargement du message",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nouveau message\nde {from}","%n nouveaux messages\nde {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Show all folders" : "Montrer tous les dossiers",
    "Collapse folders" : "Replier les dossiers",
    "Error while deleting account." : "Erreur lors de la suppression du compte.",
    "Choose a file to add as attachment" : "Choisissez un fichier à joindre au message",
    "An error occurred while uploading {fname}" : "Une erreur est survenue lors du téléversement de la pièce-jointe {fname}",
    "Reply" : "Répondre",
    "Send" : "Envoyer",
    "Sending …" : "Envoi…",
    "Message sent!" : "Message envoyé !",
    "Server error" : "Erreur du serveur",
    "An unknown error occurred" : "Une erreur inconnue est survenue",
    "Opening HTML drafts is not supported yet." : "L'ouverture de brouillons au format HTML n'est pas prise en charge pour le moment.",
    "Draft saved!" : "Brouillon sauvegardé!",
    "No writable calendars found" : "Aucun calendrier modifiable n'a été trouvé",
    "Error while importing the calendar event" : "Erreur pendant l'importation de l'évènement du calendrier",
    "Error while downloading calendar event" : "Erreur pendant le téléchargement de l'évènement du calendrier",
    "Error while loading messages." : "Erreur lors du chargement des messages.",
    "Error while refreshing messages." : "Erreur lors de l'actualisation des messages.",
    "Setting up your account" : "Paramétrage de votre compte",
    "Inbox" : "Boîte de réception",
    "Sent" : "Envoyés",
    "Drafts" : "Brouillons",
    "Archive" : "Archives",
    "Trash" : "Corbeille",
    "Junk" : "Indésirables",
    "All" : "Tous",
    "Favorites" : "Favoris",
    "Auto detect failed. Please use manual mode." : "L'auto-détection a échoué. Veuillez utiliser le mode manuel.",
    "Creating account failed: " : "La création du compte a échoué : ",
    "Delete permanently" : "Supprimer définitivement",
    "& others" : "et d'autres",
    "Error loading message" : "Erreur lors du chargement du message",
    "Settings" : "Paramètres",
    "Forwarding to %s" : "Faire suivre à %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliquer ici si vous n'êtes pas automatiquement redirigé dans les prochaines secondes.",
    "Redirect" : "Redirection",
    "The link leads to %s" : "Le lien dirige vers %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si vous ne désirez pas visiter cette page, vous pouvez retourner aux <a href=\"%s\">Mails</a>.",
    "Continue to %s" : "Continuer vers %s",
    "Delete account" : "Supprimer le compte",
    "Try again" : "Réessayez",
    "New message" : "Nouveau message",
    "Account Settings" : "Paramètres du compte",
    "Aliases" : "Alias",
    "Mail address" : "Adresse mail",
    "Display Name" : "Nom affiché",
    "Save" : "Sauvegarder",
    "Keyboard shortcuts" : "Raccourcis clavier",
    "Speed up your Mail experience with these quick shortcuts." : "Accélérez votre expérience Mail avec ces raccourcis rapides.",
    "Compose new message" : "Rédigez un nouveau message",
    "Newer message" : "Message plus récent",
    "Older message" : "Message plus ancien",
    "Toggle star" : "Épingler / Désépingler",
    "Toggle unread" : "Basculer en lu/non lu",
    "Delete" : "Supprimer",
    "Search" : "Rechercher",
    "Refresh" : "Rafraîchir",
    "Connect your mail account" : "Connecter votre compte mail",
    "Name" : "Nom",
    "Mail Address" : "Adresse mail",
    "Password" : "Mot de passe",
    "Manual configuration" : "Configuration manuelle",
    "IMAP Host" : "Hôte IMAP",
    "IMAP security" : "Sécurité IMAP",
    "None" : "Aucun",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Utilisateur IMAP",
    "IMAP Password" : "Mot de passe IMAP",
    "SMTP Host" : "Hôte SMTP",
    "SMTP security" : "Sécurité SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Connect" : "Connecter",
    "from" : "de",
    "to" : "vers",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Sujet",
    "Save all to Files" : "Enregistrer tout dans les Fichiers",
    "Add mail account" : "Ajouter un compte mail",
    "No search results for" : "Aucun résultats pour",
    "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
    "Show images from this sender" : "Voir les images de cet expéditeur",
    "Forward" : "Faire suivre",
    "No messages in this folder!" : "Aucun message dans ce dossier",
    "Upload attachment" : "Téléverser les pièces jointes",
    "Add attachment from Files" : "Ajouter des pièces jointes depuis Fichiers",
    "Import into calendar" : "Importer dans le calendrier",
    "Download attachment" : "Télécharger les pièces jointes",
    "Save to Files" : "Enregistrer dans Fichiers"
},
"nplurals=2; plural=(n > 1);");
